package com.osi.notification.destination;

import javax.jms.Destination;
import javax.management.MBeanServer;
import javax.management.MBeanServerInvocationHandler;
import javax.management.ObjectName;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.hornetq.api.jms.management.JMSServerControl;
import org.jboss.mx.util.MBeanServerLocator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class DestinationHelper {
	
	private static final Logger log = LoggerFactory
			.getLogger(DestinationHelper.class);
	private static Context ctx;
	private static JMSServerControl jmsServer;
	
	static {
		try {
			ctx = new InitialContext();
    		MBeanServer server = MBeanServerLocator.locateJBoss();
    		ObjectName name = new ObjectName("org.hornetq:module=JMS,type=Server");
    		jmsServer = 
    			(JMSServerControl)MBeanServerInvocationHandler.newProxyInstance(server, 
    					name, JMSServerControl.class, false);

		} catch (Exception e) {
			log.error("!!!! Failed to get necessary resources.", e);
		}
	}


	public static Destination createQueue(String queueName, String jndiName) throws Exception {
		log.debug("Creating Queue[{}] bound to JNDI Name[{}]", queueName, jndiName);
		if (jmsServer.createQueue(queueName, jndiName, null, false)) {
			return getDestination(jndiName);
		} else {
			throw new IllegalStateException("Failed to create Queue: " + queueName);
		}
	}
	
	public static void destroyQueue(String queueName) {
		log.debug("Destroying Queue: {}", queueName);
		try {
			jmsServer.destroyQueue(queueName);
		} catch (Exception e) {
			log.error("Error destroying queue", e);
		}
	}
	
	public static Destination getDestination(String jndiName) throws NamingException {
		return (Destination)ctx.lookup(jndiName);
	}
	
}
